/*
	Get MAC address
	Release 1.10
	Public domain code
*/

#include <stdio.h>
#include <fcntl.h>
/* /boot/optional/sample-code/drivers/EtherPCI/Driver/ether_driver.h */
#include "ether_driver.h"

void	usage	(void)
{
	fputs ("usage: getmacaddr path [port]\n", stderr);
	fputs ("Path is /dev/net/<driver>/<number>\n", stderr);
	fputs ("Port is necessary for ISA non-PnP NIC.\n", stderr);
	fputs ("Be sure to DISABLE (or remove) the NIC in Network preferences and restart networking IN ADVANCE!!!\n", stderr);
}

int	main	(int argc, char **argv)
{
	int	i, fd;
	char	*path;
	ether_address_t	ether_address;
	ether_init_params_t	ether_init = { 0x300, 10, 0xC8000 };

	/* analyze parameters */

	if (argc < 2 || 5 < argc)
	{
		usage ();
		exit (1);
	}

	path = argv [1];
	if (argc > 2)
	{
		sscanf (argv [2], "%hi", &ether_init.port);
		if (argc > 3)
		{
			sscanf (argv [3], "%hi", &ether_init.irq);
			if (argc > 4)
				sscanf (argv [4], "%li", &ether_init.mem);
		}
	}

	/* initialize */

	fd = open (path, O_RDONLY);
	if (fd < 0)
	{
		perror ("open");
		exit (1);
	}
	if (argc > 2)
		printf ("probing %s at port 0x%X\n",
			 path, (int) ether_init.port);
	else
		printf ("probing %s\n", path);
	if (ioctl (fd, ETHER_INIT, &ether_init) < 0)
	{
		perror ("ioctl (ETHER_INIT)");
		fputs ("Failed to initialize NIC.\n", stderr);
		fputs ("Be sure to DISABLE (or remove) the NIC in Network preferences and restart networking IN ADVANCE!!!\n", stderr);
		exit (1);
	}

	/* obtain and display MAC address */

	if (ioctl (fd, ETHER_GETADDR, &ether_address) < 0)
	{
		perror ("ioctl (ETHER_GETADDR)");
		fputs ("Failed to get address. \n", stderr);
		exit (1);
	}

	printf ("MAC address: ");
	for (i = 0; i < 5; i++)
		printf ("%02X:", ether_address.ebyte[i]);
	printf ("%02X\n", ether_address.ebyte[5]);

	close (fd);
}
